//[mahjong-utils](../../../index.md)/[mahjongutils.hanhu](../index.md)/[ParentPoint](index.md)/[ParentPoint](-parent-point.md)

# ParentPoint

[common]\
constructor(ron: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), tsumo: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html))
